#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mockery
version:              0.3.5
visibility:           public
id:                   mockery-0.3.5-7DaTYQsxWDx8gDDoOnN5we
key:                  mockery-0.3.5-7DaTYQsxWDx8gDDoOnN5we
license:              MIT
copyright:            (c) 2015-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Support functions for automated testing
description:          Support functions for automated testing
category:             Testing
abi:                  f0a74ea7005586f0a679d76bd4f62604
exposed:              True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging

hidden-modules:       Paths_mockery
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mockery-0.3.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mockery-0.3.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mockery
hs-libraries:         HSmockery-0.3.5-7DaTYQsxWDx8gDDoOnN5we
depends:
    base-4.18.2.1 base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    bytestring-0.11.5.3 directory-1.3.8.5 filepath-1.4.300.1
    logging-facade-0.3.1-5bQTn9kZwSNFteEYipTU3B
    temporary-1.3-EZyCN0IpTQNJIMCpUwiknJ

haddock-interfaces:   /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html:         /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

